@@ -1,10 +1,12 @@
 from .json_path_util import JsonPath, Separator
 from .graphql_query_util import graphql_query
-from .json_util import load_json
+from .json_util import load_json, obj2jsonstr
 from .path_util import replace_sys_path, get_path_by_relative
 from .yaml_util import load_yaml
 from .time_util import *
 from .object import Object
 from .arg_util import Arg, Args
+from .random_util import *
+from .file_util import write_file
 
-__version__ = "1.2.0"
+__version__ = "1.4.1"
